from pathlib import Path
from tkinter import E, END

DATA_DIR = Path(__file__).parent

INFORMATION_DATA_DIR = DATA_DIR / "information_source"
UNIT_DATA_DIR = DATA_DIR / "unit"
CENTER_DATA_DIR = DATA_DIR / "center"
EXAMINATION_DATA_DIR = DATA_DIR / "examination"
LABEL_DATA_DIR = DATA_DIR / "label"
MODEL_TYPE_DATA_DIR = DATA_DIR / "model_type"
ENDOSCOPY_PROCESSOR_DATA_DIR = DATA_DIR / "endoscopy_processor"